import { Button, Icon, Image, Tag } from 'vant'
import classNames from 'classnames'
import MusicIcon from '@/student/music/list/icons/music-icon.png'
import InitUserIcon from '@/student/music/list/icons/init-user-icon.png'
import FavoriteIcon from '@/student/music/album/favorite.svg'
import FavoritedIcon from '@/student/music/album/favorited.svg'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import { orderStatus } from '../orderStatus'

import request from '@/helpers/request'

const chargeTypes = {
  CHARGE: '点播',
  FREE: '免费',
  VIP: 'VIP'
}

export default defineComponent({
  name: 'OrderVideo',
  props: {
    modelValue: {
      type: Number,
      default: 0
    }
  },
  mounted() {
    const price = orderStatus.musicInfo.musicPrice || 0
    this.$emit('update:modelValue', price)
  },
  computed: {
    data() {
      return orderStatus.musicInfo
    }
  },
  methods: {
    async onSubmit() {
      try {
        const res = await request.post('/api-student/userOrder/executeOrder', {
          data: {
            orderName: orderStatus.musicInfo.musicSheetName,
            orderDesc: orderStatus.musicInfo.musicSheetName,
            orderType: 'MUSIC',
            actualPrice: orderStatus.musicInfo.musicPrice || 0,
            orderInfos: [
              {
                goodType: 'MUSIC',
                goodName: orderStatus.musicInfo.musicSheetName,
                bizContent: {
                  musicSheetId: orderStatus.musicInfo.id,
                  actualPrice: orderStatus.musicInfo.musicPrice || 0
                }
              }
            ]
          }
        })
        return res.data
      } catch {
        return false
      }
    }
  },
  render() {
    return (
      <div class={styles.item}>
        <header class={styles.header}>
          <div class={styles.mate}>
            <Image src={MusicIcon} round class={styles.icon} />
            <div class={styles.info}>
              <h4>{this.data.musicSheetName}</h4>
              <p>{this.data.composer}</p>
            </div>
          </div>
          <div class={styles.buttons}>
            <Button
              class={classNames(
                styles.btn,
                styles[this.data.chargeType.toLocaleLowerCase()]
              )}
              disabled
            >
              {chargeTypes[this.data.chargeType]}
              <Icon name="arrow" />
            </Button>
          </div>
        </header>
        <footer class={styles.footer}>
          <div class={styles.user}>
            <Image
              round
              src={this.data.addUserAvatar || InitUserIcon}
              class={styles.userIcon}
            />
            <p>{this.data.addName}</p>
            <div class={styles.tags}>
              {(this.data.subjectNames || '').split(',').map(item => (
                <Tag>{item}</Tag>
              ))}
            </div>
          </div>
          <div class={styles.icons}>
            {/* <Button style={{ border: 'none' }} disabled>
              <Icon
                class={styles.favorite}
                name={this.data.value ? FavoritedIcon : FavoriteIcon}
              />
            </Button> */}
          </div>
        </footer>
      </div>
    )
  }
})
