import { Cell, CellGroup, Icon, Image } from 'vant'
import { defineComponent } from 'vue'
import styles from './index.module.less'
import { orderStatus } from '../orderStatus'

import iconMember from '@common/images/icon_member.png'
import iconTimer from '@common/images/icon_timer.png'
import request from '@/helpers/request'

export default defineComponent({
  name: 'OrderVideo',
  props: {
    modelValue: {
      type: Number,
      default: 0
    }
  },
  mounted() {
    const price = orderStatus.vipInfo.price || 0
    console.log(price)
    this.$emit('update:modelValue', price)
  },
  methods: {
    async onSubmit() {
      console.log('video submit')
      try {
        const res = await request.post('/api-student/userOrder/executeOrder', {
          data: {
            orderName: '云教练' + orderStatus.vipInfo.title,
            orderDesc: '云教练' + orderStatus.vipInfo.title,
            orderType: 'VIP',
            actualPrice: orderStatus.vipInfo.price || 0,
            orderInfos: [
              {
                goodType: 'VIP',
                goodName: '云教练' + orderStatus.vipInfo.title,
                bizContent: orderStatus.vipInfo.id
              }
            ]
          }
        })
        return res.data
      } catch {
        return false
      }
    }
  },
  render() {
    return (
      <div class={styles.videoOrder}>
        <CellGroup
          class={'mb12'}
          border={false}
          style={{ borderRadius: '8px' }}
        >
          <Cell
            center
            titleClass={styles.titleClass}
            v-slots={{
              icon: () => <Image class={styles.memberLogo} src={iconMember} />,
              title: () => (
                <div class={styles.container}>
                  <div class={styles.title}>
                    云教练{orderStatus.vipInfo.title}
                  </div>
                  <div class={styles.price}>
                    <i>¥</i>
                    {(this as any).$filters.moneyFormat(
                      orderStatus.vipInfo.price
                    )}
                  </div>
                </div>
              )
            }}
          />
        </CellGroup>

        <CellGroup
          class={'mb12'}
          border={false}
          style={{ borderRadius: '8px' }}
        >
          <Cell
            center
            v-slots={{
              title: () => (
                <div class={styles.container}>
                  <div class={styles.timerTitle}>
                    <Icon name={iconTimer} size={18} />
                    <span style={{ paddingLeft: '5px' }}>生效时间</span>
                  </div>
                  <div class={styles.timer}>
                    {orderStatus.vipInfo.startTime} 至{' '}
                    {orderStatus.vipInfo.endTime}
                  </div>
                </div>
              )
            }}
          />
        </CellGroup>
      </div>
      // 视频课
    )
  }
})
